# Reminders for using MkDocs

This will likely get deleted soon, but I just want a place to store reminders of the workflow here...

For full documentation visit [mkdocs.org](https://www.mkdocs.org).
test
## Commands

* `mkdocs new [dir-name]` - Create a new project.
* `mkdocs serve` - Start the live-reloading docs server.
* `mkdocs build` - Build the documentation site.
* `mkdocs -h` - Print help message and exit.

## Project layout

    mkdocs.yml    # The configuration file.
    docs/
        index.md  # The documentation homepage.
        ...       # Other markdown pages, images and other files.
